"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.closeOpenedTextFile = exports.checkTextFileIsOpened = exports.awaitForDocumentBeingSaved = exports.setFileSaved = void 0;
const vscode = require("vscode");
const constants_1 = require("../config/constants");
/**
 * Opens the next tab in editor with given delay
 */
function openNextTab(delay) {
    return new Promise((resolve) => {
        vscode.commands.executeCommand("workbench.action.nextEditor");
        setTimeout(() => resolve(), delay);
    });
}
let fileWasSaved = false;
function setFileSaved(status) {
    fileWasSaved = status;
}
exports.setFileSaved = setFileSaved;
function awaitForDocumentBeingSaved() {
    return __awaiter(this, void 0, void 0, function* () {
        fileWasSaved = false;
        return new Promise((resolve) => {
            let count = 0;
            const saveWaitIntervalId = setInterval(() => {
                if (constants_1.workspaceUtilFileSaveMaxIterationCount > count) {
                    count++;
                    if (fileWasSaved) {
                        fileWasSaved = false;
                        clearInterval(saveWaitIntervalId);
                        resolve();
                    }
                }
                else {
                    clearInterval(saveWaitIntervalId);
                    resolve();
                }
            }, constants_1.workspaceUtilFileSaveInterval);
        });
    });
}
exports.awaitForDocumentBeingSaved = awaitForDocumentBeingSaved;
/**
 * Checks if file is opened using iteration through tabs
 * This kind of method is caused by incompleteness of VSCode API, which allows to check only buffered status of files
 * There's an issue on GitHub for such feature: https://github.com/Microsoft/vscode/issues/15178 let's track it
 * Idea of the approach was borrowed from the another extension: https://github.com/eamodio/vscode-restore-editors/blob/master/src/documentManager.ts
 * Also notice that timer delay as well as iteration through opened tabs can cause side-effects on slow machines
 */
function checkTextFileIsOpened(path) {
    return __awaiter(this, void 0, void 0, function* () {
        const openedWindows = [];
        let emptySelectedCountInTheRow = 0;
        let selectedEditor = vscode.window.activeTextEditor;
        // The idea of the condition is we can meet binary files opened, which have no text editor
        // So we should set some maximum occurrences point and get out of the loop
        while (emptySelectedCountInTheRow < constants_1.workspaceUtilMaxEmptyWindowsInTheRow &&
            !openedWindows.some((window) => selectedEditor && window.id === selectedEditor.id)) {
            if (selectedEditor) {
                emptySelectedCountInTheRow = 0;
                openedWindows.push(selectedEditor);
            }
            else {
                emptySelectedCountInTheRow++;
            }
            yield openNextTab(constants_1.workspaceUtilTabSwitchDelay);
            selectedEditor = vscode.window.activeTextEditor;
        }
        return openedWindows.some((window) => window.document.fileName === path);
    });
}
exports.checkTextFileIsOpened = checkTextFileIsOpened;
/**
 * Closes opened file tab using iteration through the tabs
 * This kind of method is caused by incompleteness of VSCode API, which allows to close only currently selected editor
 * For us it means we need to select editor first, which is again not possible via existing VSCode APIs
 */
function closeOpenedTextFile(path) {
    return __awaiter(this, void 0, void 0, function* () {
        const openedWindows = [];
        let emptySelectedCountInTheRow = 0;
        let selectedEditor = vscode.window.activeTextEditor;
        // The idea of the condition is we can meet binary files opened, which have no text editor
        // So we should set some maximum occurrences point and get out of the loop
        while (emptySelectedCountInTheRow < constants_1.workspaceUtilMaxEmptyWindowsInTheRow &&
            !openedWindows.some((window) => selectedEditor && window.id === selectedEditor.id)) {
            if (selectedEditor) {
                emptySelectedCountInTheRow = 0;
                openedWindows.push(selectedEditor);
            }
            else {
                emptySelectedCountInTheRow++;
            }
            yield openNextTab(constants_1.workspaceUtilTabSwitchDelay);
            selectedEditor = vscode.window.activeTextEditor;
            if (selectedEditor && selectedEditor.document.fileName === path) {
                const isDirty = selectedEditor.document.isDirty;
                yield vscode.commands.executeCommand("workbench.action.closeActiveEditor");
                if (isDirty) {
                    yield awaitForDocumentBeingSaved();
                }
                return true;
            }
        }
        return false;
    });
}
exports.closeOpenedTextFile = closeOpenedTextFile;

//# sourceMappingURL=workspace.js.map
